@@ -10,7 +10,7 @@ log_dir = pkg_resources.resource_filename("diyepw", "log")
 if not os.path.exists(log_dir): # pragma: no cover
     os.mkdir(log_dir)
 
-_log_path = os.path.join(log_dir, str(datetime.now()).replace(' ', '_') +'.log')
+_log_path = os.path.join(log_dir, str(datetime.now()).replace(' ', '_').replace(':', '_') +'.log')
 _file_handler = logging.FileHandler(_log_path)
 _file_handler.setFormatter(logging.Formatter("%(asctime)s [diyepw.%(levelname)s] %(message)s"))
 _file_handler.setLevel(_LOG_LEVEL)
@@ -21,4 +21,4 @@ _stdout_handler.setLevel(_LOG_LEVEL)
 
 _logger = logging.Logger('diyepw')
 _logger.addHandler(_stdout_handler)
-_logger.addHandler(_file_handler)
\ No newline at end of file
+_logger.addHandler(_file_handler)
